package com.tourism.webadmin.app.website.controller;

import cn.dev33.satoken.annotation.SaIgnore;
import com.tourism.common.core.object.MyPageData;
import com.tourism.common.core.object.ResponseResult;
import com.tourism.common.log.annotation.OperationLog;
import com.tourism.common.log.model.constant.SysOperationLogType;
import com.tourism.webadmin.app.website.dto.TourismProjectTravelNotesToWebDto;
import com.tourism.webadmin.app.website.service.BasicToWebService;
import com.tourism.webadmin.back.service.TourTourismProjectTravelNotesService;
import com.tourism.webadmin.back.service.TourUserLikeTravelNotesService;
import com.tourism.webadmin.back.vo.TourTourismProjectTravelNotesVo;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@Tag(name = "门户网站旅游游记接口")
@Slf4j
@RestController
@SaIgnore
@Validated
@RequestMapping("/website/tourism/projectTravelNotes")
public class WebsiteTourismProjectTravelNotesController {

    @Autowired
    private BasicToWebService basicToWebServicel;
    @Autowired
    private TourTourismProjectTravelNotesService tourTourismProjectTravelNotesService;


    /**
     * 列出旅游游记列表。(首页)
     * @return 应答结果对象，包含查询结果集。
     */
    @OperationLog(type = SysOperationLogType.LIST)
    @GetMapping("/homeList")
    public ResponseResult<MyPageData<TourTourismProjectTravelNotesVo>> tourTourismTravelNotesList(TourismProjectTravelNotesToWebDto tourismProjectTravelNotesToWebDto) {
        MyPageData<TourTourismProjectTravelNotesVo> tourTourismProjectTravelNotesList = basicToWebServicel.getTourTourismProjectTravelNotesList(tourismProjectTravelNotesToWebDto);

        return ResponseResult.success(tourTourismProjectTravelNotesList);
    }

    /**
     * 列出符合过滤条件的旅游游记列表。(游记页)
     * @return 应答结果对象，包含查询结果集。
     */
    @OperationLog(type = SysOperationLogType.LIST)
    @GetMapping("/travelNotesPageList")
    public ResponseResult<MyPageData<TourTourismProjectTravelNotesVo>> travelNotesPageList(@Validated TourismProjectTravelNotesToWebDto tourismProjectTravelNotesToWebDto) {
        MyPageData<TourTourismProjectTravelNotesVo> tourTourismProjectTravelNotesList = basicToWebServicel.getTravelNotesPageList(tourismProjectTravelNotesToWebDto);

        return ResponseResult.success(tourTourismProjectTravelNotesList);
    }

    /**
     * 通过旅游游记的id查询游记的详情。
     * @return 应答结果对象，包含查询结果集。
     */
    @OperationLog(type = SysOperationLogType.LIST)
    @GetMapping("/travelNotesDetail")
    public ResponseResult<TourTourismProjectTravelNotesVo> travelNotesDetail(@RequestParam Long id) {

        return ResponseResult.success(basicToWebServicel.travelNotesDetail(id));
    }

    /**
     * 用户游记点赞
     * param travelNotesId 游记id
     * param type 0取消点赞 1点赞
     * @return 应答结果对象，包含查询结果集。
     */
    @OperationLog(type = SysOperationLogType.UPDATE)
    @GetMapping("/userLikeTravelNotesUpdate")
    public ResponseResult<Void> userLikeTravelNotesUpdate(@RequestParam Long travelNotesId,Integer type) {

        basicToWebServicel.userLikeTravelNotesUpdate(travelNotesId,type);
        return ResponseResult.success();
    }

    /**
     * 用户是否对该游记进行点赞
     * param travelNotesId 游记id
     * @return 应答结果对象，包含查询结果集。
     */
    @OperationLog(type = SysOperationLogType.ADD)
    @GetMapping("/isLikeTravelNotes")
    public ResponseResult<Boolean> isLikeTravelNotes(@RequestParam Long travelNotesId) {
        return ResponseResult.success(basicToWebServicel.isLikeTravelNotes(travelNotesId));
    }


    /**
     * 用户游记增加浏览量
     * param travelNotesId 游记id
     * @return 应答结果对象，包含查询结果集。
     */
    @OperationLog(type = SysOperationLogType.ADD)
    @GetMapping("/travelNotesViewCountAdd")
    public ResponseResult<Void> travelNotesViewCountAdd(@RequestParam Long travelNotesId) {
        basicToWebServicel.travelNotesViewCountAdd(travelNotesId);
        return ResponseResult.success();
    }
}
